@@ -259,6 +259,7 @@ class UploadFirmwareFrame(tk.Frame, PicoFrame):
         tk.Frame.__init__(self, master)
 
         self._is_uploading_done = False
+        self._is_status_update_done = False
 
         self.grid(row=0, column=0, sticky='nsew')
         self.grid_rowconfigure(0, weight=0)
@@ -321,6 +322,8 @@ class UploadFirmwareFrame(tk.Frame, PicoFrame):
             self._board = None
 
     def _upload_firmware(self):
+        self._is_status_update_done = False
+        self._is_uploading_done = False
         self._uploading_label.start_loading()
         self.master.update_status_bar('Uploading firmware')
         self._update_thread = threading.Thread(target=self._upload_helper)
@@ -331,10 +334,10 @@ class UploadFirmwareFrame(tk.Frame, PicoFrame):
         self._upload_button.state(["disabled"])
         self._boards_tree_view.state(["disabled"])
         self._boards_tree_view.unbind('<ButtonRelease-1>')
-        self._is_uploading_done = False
         try:
             if not NO_UPLOAD:
                 upload_firmware(Boards(self._board))
+                self._is_status_update_done = True
         except RuntimeError as e:
             self.master.update_status_bar("Selected '%s'" % self._board)
             messagebox.showerror(title='Error', message=str(e))
@@ -342,6 +345,7 @@ class UploadFirmwareFrame(tk.Frame, PicoFrame):
             self._boards_tree_view.state(["!disabled"])
             self._boards_tree_view.bind('<ButtonRelease-1>', self._update_selected_board)
             self._uploading_label.stop_loading()
+            self._is_status_update_done = True
         else:
             self._is_uploading_done = True
 
@@ -349,10 +353,12 @@ class UploadFirmwareFrame(tk.Frame, PicoFrame):
         if self._is_uploading_done:
             self.master.update_status_bar("Connected to '%s'" % self._board)
             self.draw_next_frame()
-        else:
+        elif not self._is_status_update_done:
             n = (n + 1) % 10
             self.master.update_status_bar('Uploading firmware  ▏' + '▊' * n + '▁' * (9 - n) + '▕')
             self.after(200, self._check_uploading, n)
+        else:
+            self.master.update_status_bar("Selected '%s'" % self._board)
 
     def clean(self):
         pass
@@ -386,6 +392,7 @@ class UploadModelsFrame(tk.Frame, PicoFrame):
 
         self._uuid = None
         self._is_uploading_done = False
+        self._is_status_update_done = False
         self._is_responded = False
         self._selected_models = dict(porcupine=DEFAULT_PORCUPINE_MODEL, rhino=DEFAULT_RHINO_MODEL)
 
@@ -556,18 +563,23 @@ class UploadModelsFrame(tk.Frame, PicoFrame):
                 break
 
         if not self._is_connecting_done:
+            self._is_status_update_done = True
             messagebox.showerror(title='Error', message='No serial connection was detected for %s' % self._board)
             self.master.update_status_bar("Selected '%s'" % self._board)
             self.master.draw_upload_firmware_frame()
 
     def _check_connecting(self, n):
         if self._is_connecting_done:
+            self._is_status_update_done = True
             self.master.update_status_bar("Connected to '%s'" % self._board)
             self.after(200, self._get_uuid)
-        else:
+        elif not self._is_status_update_done:
             n = (n + 1) % 10
             self.master.update_status_bar('Connecting to the board  ▏' + '▊' * n + '▁' * (9 - n) + '▕')
             self.after(200, self._check_connecting, n)
+        else:
+            self.master.update_status_bar('No serial connection was detected for %s' % self._board)
+
 
     def _get_uuid(self):
         if not self._is_responded:
@@ -586,6 +598,8 @@ class UploadModelsFrame(tk.Frame, PicoFrame):
             self._select_porcupine_model_button.state(["!disabled"])
 
     def _upload_models(self):
+        self._is_uploading_done = False
+        self._is_status_update_done = False
         self.master.update_status_bar('Uploading models')
         self.update_Thread = threading.Thread(target=self._upload_models_helper)
         self.update_Thread.start()
@@ -594,10 +608,13 @@ class UploadModelsFrame(tk.Frame, PicoFrame):
     def _check_uploading(self, n):
         if self._is_uploading_done:
             self.draw_next_frame()
-        else:
+        elif not self._is_status_update_done:
             n = (n + 1) % 10
             self.master.update_status_bar('Uploading models ▏' + '▊' * n + '▁' * (9 - n) + '▕')
             self.after(200, self._check_uploading, n)
+        else:
+            self.master.update_status_bar("Connected to '%s'" % self._board)
+
 
     def _upload_models_helper(self):
         if not NO_UPLOAD:
@@ -624,6 +641,7 @@ class UploadModelsFrame(tk.Frame, PicoFrame):
                             rhn_path=self._rhino_model_path,
                             board=Boards(self._board))
                 except RuntimeError as e:
+                    self._is_status_update_done = True
                     self.master.update_status_bar("Connected to '%s'" % self._board)
                     messagebox.showerror(title='Error', message=str(e))
                     self._upload_label.stop_loading()
@@ -633,6 +651,7 @@ class UploadModelsFrame(tk.Frame, PicoFrame):
                     self._select_rhino_model_button.state(["!disabled"])
                 else:
                     self._is_uploading_done = True
+                    self._is_status_update_done = True
         else:
             self._is_uploading_done = True
 
@@ -1077,7 +1096,6 @@ class MonitoringCenter(tk.Frame):
                 log.debug(error)
 
         elif code is MessageCode.PV_MESSAGE_CODE_ERROR.value[0]:
-            print('hi')
             self._log_scrolled_text.insert('end', ' %s\n' % payload, 'ERROR')
             self._log_scrolled_text.see('end')
             self.master.invalid_state()
